%To start with, let's make it simple: 1 speaker; 2 microphone pairs
% first speaker: linearly moving at 45
% second speaker: doesn't move

fcode='test2';

fs= 8000;     %sampling rate
Nspkr= 1;           %no. of speakers
Nframe= 1024;   %channel impulse response update frame length
block_overlap= 1;   %block overlap factor for computing TDOAs
                    %always 1 for now
L= 30;              %no. of frames
N= L*Nframe;
Psensor= 4;           %no. of TDOA microphone pairs
P= Psensor;     %just for convenience of programming

snr_db= 16;
snr= 10^(snr_db/10);
Ts= 1/fs;


%--- parameters associated with room impulse responses
c= 344;			%speed of sound
rlim= 1;			%represent (but not exactly) the no. of multipaths
room_dim= [ 3; 3; 2.5 ];    %room size
%beta= [ 0.85 0.85 0.75; 0.85 0.85 0.5 ];	%reflection coefficients of walls
beta= 1e-6*ones(2,3);

%speaker coordinate
x_spkr= zeros(3,L,Nspkr); k_birth= zeros(Nspkr,1); k_death= zeros(Nspkr,1);
%speaker 1
k_birth(1)= 1; k_death(1)= 30;
for el=k_birth(1):k_death(1)
    x_spkr(:,el,1)= [ 1; 1; 1.8 ]+ [ (el-1)*0.06; (el-1)*0.06; 0 ];
end;
%speaker 2
k_birth(2)= 21; k_death(2)= 45;
theta= 0;
for el=k_birth(2):k_death(2)
    x_spkr(:,el,2)= [ 0.5+2*cos(theta); 0.5+2*sin(theta); 1.8 ];
    theta= theta+ (pi/2)/50;
end;
%x_spkr(:,k_birth(2):k_death(2),2)= repmat([.5; 2.3; 1.8],1,(k_death(2)-k_birth(2)+1));

x_sensor= zeros(3,2,P);     %microphone pair coordinates
x_sensor(:,1,1)= [ 1.25; 0.01; 1.8 ]; x_sensor(:,2,1)= [ 1.75; 0.01; 1.8 ];
x_sensor(:,1,2)= [ 0.01; 1.25; 1.8 ]; x_sensor(:,2,2)= [ 0.01; 1.75; 1.8 ];
x_sensor(:,1,3)= [ 1.25; 2.99; 1.8 ]; x_sensor(:,2,3)= [ 1.75; 2.99; 1.8 ];
x_sensor(:,1,4)= [ 2.99; 1.25; 1.8 ]; x_sensor(:,2,4)= [ 2.99; 1.75; 1.8 ];

dR= c*Ts;
max_d= ceil(.5/dR);       %max. no. of TDOA samples (.5 is the microphone pair spacing)


%---
h_len= 3000;      %length of room impulses responses

if exist(['roomir_',fcode,'.mat'],'file'), gen_ir= 'n'; 
else gen_ir= 'y'; end;

if gen_ir=='y',
    disp(['Computing the room impulse responses...']);
    h= cell(Nspkr,1);
    for n=1:Nspkr
        h{n}= zeros(h_len,2,P,k_death(n)-k_birth(n)+1);
        for p=1:P
            for el=k_birth(n):k_death(n)
                h{n}(:,1,p,el-k_birth(n)+1)= ...
                    ir_room2(x_spkr(:,el,n)/dR,x_sensor(:,1,p)/dR,room_dim/dR,beta,h_len,rlim);
                h{n}(:,2,p,el-k_birth(n)+1)= ...
                    ir_room2(x_spkr(:,el,n)/dR,x_sensor(:,2,p)/dR,room_dim/dR,beta,h_len,rlim);
            end;
        end;
    end;
    save( ['roomir_',fcode], 'h' );
else
    load(['roomir_',fcode]);
end;

%--- load speech signals
s= cell(Nspkr,1);
wav_file= cell(Nspkr,1);
wav_file{1}= 'si1752'; wav_file{2}= 'sx267_2';
for n=1:Nspkr
    st= wavread(wav_file{n}); st= decimate(st,2);
    sig_len= (k_death(n)-k_birth(n)+1)*Nframe;
    if length(st) > sig_len
        s{n}= st(1:sig_len);
    else
        s{n}= zeros(sig_len,1); s{n}(1:length(st))= st;
    end;
end;

%test: check out what happens when there is no signal
%t_len=length(s{1});
%s{1}= zeros(t_len,1);