%==== This M.file declares the tracking problem structure ===
% here we declare a 3-D constant velocity model with TDOA
% measurements. Q pairs of sensors (each pair computes a TDOA) are used.
% This code also establishes connection between TDOA extraction and MPHD.

%=== the following parameters is directly assessed by 
% siggen.m and phdfilter.m
K= L;  %data length
x_dim= 4;   %dimension of state vector
z_dim= 1;   %dimension of observation vector
%lambda_b= .25;  %average rate of target birth (per scan)
P_birth= 1;  %target birth probability
P_death= 0;  %probability of target death
P_D= .75;   %probability of detection in measurements
lambda_c= 3;   %average rate of clutter (per scan)
range_c= [ -max_d max_d ]*dR;    %clutter intervals

%=== particle filter parameters
Ns= 500;   %no. of particles
%Lmax= 1e5;  %max. allowable particles
%rho= 2000;  %no. of particles per survived target
%Jk= 8000;   %no. of particles for birth targets
%gamma= 1e5; Jk= ceil(gamma*lambda_b);

%=== the following parameters are more problem dependent
% 'siggen', 'phdfilter', etc. do not assess these parameters directly.
% These parameters are used by problem dependent functions such as
%
% gen_newstate, gen_birthstate, gen_observation, compute_likelihood
% 
% we create a structure array 'model' to store these specific parameters

%here we set up the state spc eqn. x= Ax_old + Bv
%that's Langevin model
T= Nframe*Ts;   %snapshot period
sigma_motion= 1;     %in m/s
beta_motion= 10;    %in 1/s

A0= [ 1 T; 0 exp(-beta_motion*T) ];                       
model.A= [ A0 zeros(2,2); zeros(2,2) A0 ];
B0= [ 0; sigma_motion*sqrt(1-exp(-2*beta_motion*T)) ];
model.B= [ B0 zeros(2,1); zeros(2,1) B0 ];
model.sigma_v= 1;
%here is the parameter for the birth target states
%assume uniform distribution with zero vel.
model.posn_interval= [ 0 room_dim(1); 0 room_dim(2) ];
% parameters for the observation 
model.C_xy_posn= [ 1 0 0 0 ; 0 0 1 0  ];
model.C_posn= model.C_xy_posn;
model.D= dR;   %std for TDOA
%model.D= .1;   %std for TDOA
Q= Psensor;                           %no. of sensors
model.sensor_posns= zeros(3,2,Q); %sensor location vectors: 1col vector is reference sensor posn.
for q=1:Q
    model.sensor_posns(:,:,q)= [ x_sensor(:,sensor_pair_idx(1,q)) x_sensor(:,sensor_pair_idx(2,q)) ];
end;

%=== allocate TDOA variables to MPHD
Z= cell(Q,K);
for q=1:Q
    for k=1:K
        Z{q,k}= tdoa_peaks{k,q}*dR; %conversion of TDOA to relative dist.
    end;
end;

N_true= ones(K,1);
track_list= cell(K,1);
X= cell(K,1);
W= [ 1 0 0; 0 0 0; 0 1 0; 0 0 0 ];
for n=1:Nspkr
    for k=k_birth(n):k_death(n)
        N_true(k)= N_true(k)+1;
        X{k}= [ X{k} W*x_spkr(:,n) ];
        track_list{k}= [ track_list{k} n ];
    end;
end;
total_tracks= Nspkr;

