%==== This M.file declares the problem structure common to all algorithms
% motion model: Langevin
% TDOA measurements

K= L;  %data length
x_dim= 4;   %dimension of state vector
z_dim= 1;   %dimension of observation vector

range_c= [ -max_d max_d ]*dR;    %clutter intervals

%here we set up the state spc eqn. x= Ax_old + Bv
%that's Langevin model
T= Nframe*Ts;   %snapshot period
sigma_motion= 1;     %in m/s
beta_motion= 10;    %in 1/s

A0= [ 1 T; 0 exp(-beta_motion*T) ];                       
model.A= [ A0 zeros(2,2); zeros(2,2) A0 ];
B0= [ 0; sigma_motion*sqrt(1-exp(-2*beta_motion*T)) ];
model.B= [ B0 zeros(2,1); zeros(2,1) B0 ];
model.sigma_v= 1;

%here is the parameter for the birth target states
%assume uniform distribution with zero vel.
model.posn_interval= [ 0 room_dim(1); 0 room_dim(2) ];

% parameters for the observation 
model.C_xy_posn= [ 1 0 0 0 ; 0 0 1 0  ];
model.C_posn= model.C_xy_posn;
model.D= dR;   %std for TDOA
%model.D= .1;   

% sensor positions
Q= Psensor;                           %no. of sensors
model.sensor_posns= zeros(3,2,Q); %sensor location vectors: 1col vector is reference sensor posn.
for q=1:Q
    model.sensor_posns(:,:,q)= [ x_sensor(:,sensor_pair_idx(1,q)) x_sensor(:,sensor_pair_idx(2,q)) ];
end;

%=== allocate TDOA variables to Z
Z= cell(Q,K);
for q=1:Q
    for k=1:K
        Z{q,k}= tdoa_peaks{k,q}*dR; %conversion of TDOA to relative dist.
    end;
end;

N_true= zeros(K,1);
track_list= cell(K,1);
X= cell(K,1);
W= [ 1 0 0; 0 0 0; 0 1 0; 0 0 0 ];
for n=1:Nspkr
    for k=k_birth(n):k_death(n)
        N_true(k)= N_true(k)+1;
        X{k}= [ X{k} W*x_spkr(:,n) ];
        track_list{k}= [ track_list{k} n ];
    end;
end;
total_tracks= Nspkr;

