function h= ir_room( x_spker, x_sensor, room_dim, beta, N, dim_of_images, lpass )
%
% debugged in Feb 2004
%
% simulation of acoustic room impulse response (using the image method)
% h= ir_room( x_spker, x_sensor, room_dim, beta, N, dim_of_images )
%
% x_spkr= [x,y,z]' is the speaker location
% x_sensor= [x,y,z]' is the sensor location
% room_dim= [Lx,Ly,Lz] is the room size.
% beta= [ beta_x1 beta_y1 beta_z1; beta_x2 beta_y2 beta_z2 ]
%   contains the reflection coefficients of the walls.
% N is the length of the room impulse response
% dim_of_images is the no. of images used
%
% a lowpass filtering is applied to the room impulse response for practical reasons.
% lpass.len is the half length of the lowpass filter 
%   (i.e., total filter length= lpass.len*2+1)
% lpass.Wn is the passband (in normalized frequency, 0 <= Wn <=1).
%
% N.B.: always use a very large N (like 4096) otherwise aliasing error may occur


if nargin <=6,
   lpass.len= 100;
   lpass.Wn= .9;
end;
N2= N+(2*lpass.len+1)-1;

%--------
Rp= zeros(3,8);
for p=1:8
   str= dec2bin(p-1,3);
   v= [ str2num(str(1))*2-1 str2num(str(2))*2-1 str2num(str(3))*2-1 ]';
   Rp(:,p)= x_spker+ v.*x_sensor;
end;

%--------
H= zeros(N2,1);
omega= 2*pi*(0:1:(N2-1))'./N2;
for p=1:8
   str= dec2bin(p-1,3); v= [ str2num(str(1)); str2num(str(2)); str2num(str(3)) ];
   for n=-dim_of_images:1:dim_of_images
      for l= -dim_of_images:1:dim_of_images
         for m= -dim_of_images:dim_of_images
            Rr= 2*[ n; l; m].*room_dim;
            D= norm(Rp(:,p)+Rr);
            if D < N,
            	H= H+ (beta(1,1)^abs(n-v(1)))*(beta(2,1)^abs(n))* ...
               	(beta(1,2)^abs(l-v(2)))*(beta(2,2)^abs(l))*(beta(1,3)^abs(m-v(3)))*(beta(2,3)^abs(m))* ...
                  exp(-j*omega.*D)./(4*pi*D);
            end;
         end;
      end;
   end;
end;

f_lp= fir1(lpass.len*2,lpass.Wn)';
F_lp= fft([f_lp; zeros(N2-length(f_lp),1)]);
H= H.*F_lp;
h= real(ifft(H));
h= h((lpass.len+1):(N2-lpass.len));
