%To start with, let's make it simple: 1 speaker; 2 microphone pairs

fcode='test1';

fs= 8000;     %sampling rate
interp_factor= 6;   %interpolation factor for generating multiple signals
K= 1;           %no. of speakers
Nframe= 1024*8;   %FFT frame length
P= 2;           %no. of TDOA microphone pairs

snr_db= 100;
snr= 10^(snr_db/10);
Ts= 1/fs;


%--- parameters associated with room impulse responses
c= 344;			%speed of sound
rlim= 5;			%represent (but not exactly) the no. of multipaths
room_dim= [ 3; 3; 2.5 ];    %room size
beta= [ 0.85 0.85 0.75; 0.85 0.85 0.5 ];	%reflection coefficients of walls
%beta= 1e-6*ones(2,3);

%x_s= [ 1; 2; 1.5 ];  %speaker coordinate
x_s= [ 1.2; 1.8; 1.5 ];
x_sensor= zeros(3,2,P);     %microphone pair coordinates
x_sensor(:,1,1)= [ 1.25; 0.01; 2.4 ]; x_sensor(:,2,1)= [ 1.75; 0.01; 2.4 ];
x_sensor(:,1,2)= [ 0.01; 1.25; 2.4 ]; x_sensor(:,2,2)= [ 0.01; 1.75; 2.4 ];

max_d= ceil(.5/(c*Ts));       %max. no. of TDOA samples (.5 is the microphone pair spacing)


%---
dR= c*Ts/interp_factor; %spatial length per interpolated sample
h_len= 2048*4;      %length of room impulses responses (interpolated)

if exist(['roomir_',fcode,'.mat'],'file'), gen_ir= 'n'; 
else gen_ir= 'y'; end;

if gen_ir=='y',
    disp(['Computing the room impulse responses...']);
    h= zeros(h_len,2,P);
    for p=1:P
        h(:,1,p)= ir_room2(x_s/dR,x_sensor(:,1,p)/dR,room_dim/dR,beta,h_len,rlim);
        h(:,2,p)= ir_room2(x_s/dR,x_sensor(:,2,p)/dR,room_dim/dR,beta,h_len,rlim);
    end;
    save( ['roomir_',fcode], 'h' );
else
    load(['roomir_',fcode]);
end;

%--- load speech signals
s= wavread('SA2');	s= decimate(s,2); % desired speech
%s= randn(10*Nframe,1);

N= length(s);
N= ceil(N/Nframe)*Nframe; 	%modify data length
L= N/Nframe;					%no. of frames

st= s; s= zeros(N,1); s(1:length(st))= st;	%modify s to fit new length
s= s./(norm(s)./sqrt(N));			%normalize its power