%==== Multi-sensor 2 target Bayesian filtering:
% run this routine after you call 'declare_problem_single' and signal generation


%---
hat_N= zeros(K,1);      %(soft) estimate of the number of targets
particle_X= cell(K,1);  %cell for storing all particles
particle_W= cell(K,1);  %cell for storing the update weights
Wk= ones(Ns,1)/Ns;
X1k= zeros(x_dim,Ns); X2k= zeros(x_dim,Ns);
N1k= zeros(Ns,1); N2k= zeros(Ns,1);

for k=1:K
    k
    time_start= cputime;
    Nk_old= N1k+ N2k;
    %--- death & survival ---
    idx= find( N1k==1 );
    rv= rand(length(idx),1); idx2= find(rv>P_death);
    surv_idx= idx(idx2);
    if ~isempty(surv_idx),
        X1k(:,surv_idx)= gen_newstate(model,X1k(:,surv_idx));
    end;
    N1k= zeros(Ns,1); N1k(surv_idx)= 1;
    idx= find( N2k==1 );
    rv= rand(length(idx),1); idx2= find(rv>P_death);
    surv_idx= idx(idx2);
    if ~isempty(surv_idx),
        X2k(:,surv_idx)= gen_newstate(model,X2k(:,surv_idx));
    end;
    N2k= zeros(Ns,1); N2k(surv_idx)= 1;
    %--- stacking ---
    idx= find( N1k==0 & N2k==1 );
    X1k(:,idx)= X2k(:,idx);
    N1k(idx)= 1; N2k(idx)= 0;
    %--- Birth ---
    idx= find( Nk_old<2 );
    rv= rand(length(idx),1);
    idx2= find(rv<=P_birth);
    birth_idx= idx(idx2);
    X2k(:,birth_idx)= gen_birthstate(model,length(birth_idx));
    N2k(birth_idx)= 1;
    %--- stacking ---
    idx= find( N1k==0 & N2k==1 );
    X1k(:,idx)= X2k(:,idx);
    N1k(idx)= 1; N2k(idx)= 0;
    %--- weight update ---
    phi= lambda_c/prod(range_c(:,2)-range_c(:,1));
    idx_1t= find( N1k+N2k== 1 );
    idx_2t= find( N1k+N2k== 2 );
    %1 target
    for q=1:Q
        Zk_len= size(Z{q,k},2);
        f_zx= zeros(length(idx_1t),1);       
        for i=1:Zk_len
            f_zx= f_zx+ compute_likelihood(model,Z{q,k}(:,i),X1k(:,idx_1t),q)';
        end;
        Wk(idx_1t)= Wk(idx_1t).*( (1-P_D)+ P_D*f_zx/phi );
    end;
    %2 targets
    for q=1:Q
        Zk_len= size(Z{q,k},2);
        f_zx1= zeros(length(idx_2t),1); f_zx2= zeros(length(idx_2t),1);
        f_zx12= zeros(length(idx_2t),1);
        for i=1:Zk_len
            t1= compute_likelihood(model,Z{q,k}(:,i),X1k(:,idx_2t),q)';
            t2= compute_likelihood(model,Z{q,k}(:,i),X2k(:,idx_2t),q)';
            f_zx1= f_zx1+ t1;
            f_zx2= f_zx2+ t2;
            f_zx12= f_zx12+ t1.*t2;
        end;
        Wk(idx_2t)= Wk(idx_2t).*( ...
            ( (1-P_D)+ P_D*f_zx1/phi ).*( (1-P_D)+ P_D*f_zx2/phi ) - ...
            f_zx12*(P_D/phi)^2 );
    end;
    % --- weight normalization and resampling ---
    Wk= Wk/sum(Wk);
    hat_N(k)= Wk'*(N1k+N2k); 
    particle_W{k}= Wk;
    %idx_k1= find( N1k==1 ); idx_k2= find( N2k==1 );
    %particle_X{k}= [ X1k(:,idx_k1) X2k(:,idx_k2) ];
    idx= resample(Wk,Ns);
    X1k= X1k(:,idx); N1k= N1k(idx);
    X2k= X2k(:,idx); N2k= N2k(idx);
    Wk= ones(Ns,1)/Ns;
    idx_k1= find( N1k==1 ); idx_k2= find( N2k==1 );
    particle_X{k}= [ X1k(:,idx_k1) X2k(:,idx_k2) ];
end;


        
