%==== This M.file declares the tracking problem structure ===
% here we declare a 3-D constant velocity model with TDOA
% measurements. Q pairs of sensors (each pair computes a TDOA) are used.
% This code also establishes connection between TDOA extraction and MPHD.

%=== the following parameters is directly assessed by 
% siggen.m and phdfilter.m
K= L;  %data length
x_dim= 5;   %dimension of state vector
z_dim= 1;   %dimension of observation vector
lambda_b= .25;  %average rate of target birth (per scan)
P_death= 0.01;  %probability of target death
P_D= .9;   %probability of detection in measurements
lambda_c= 2;   %average rate of clutter (per scan)
range_c= [ -max_d max_d ]*dR;    %clutter intervals

%=== PHD filter parameters
Lmax= 1e5;  %max. allowable particles
rho= 2000;  %no. of particles per survived target
Jk= 8000;   %no. of particles for birth targets
%gamma= 1e5; Jk= ceil(gamma*lambda_b);

%=== the following parameters are more problem dependent
% 'siggen', 'phdfilter', etc. do not assess these parameters directly.
% These parameters are used by problem dependent functions such as
%
% gen_newstate, gen_birthstate, gen_observation, compute_likelihood
% 
% we create a structure array 'model' to store these specific parameters

%here we set up the state spc eqn. x= Ax_old + Bv
T= Nframe*Ts;   %snapshot period
sigma_motion_xy= .1;     %in m/s^2
sigma_motion_z= 0.01;   %in m/s^2

A0= [ 1 T; 0 1 ];                       
model.A= [ A0 zeros(2,3); zeros(2,2) A0 zeros(2,1); zeros(1,4) 1 ];
B0= sigma_motion_xy*[ (T^2)/2; T ];
model.B= [ B0 zeros(2,2); zeros(2,1) B0 zeros(2,1); zeros(1,2) T*sigma_motion_z ];
model.sigma_v= 1;
%here is the parameter for the birth target states
%assume uniform distribution with zero vel.
model.posn_interval= [ 0 3; 0 3; 0 2.5 ];
% parameters for the observation 
model.C_posn= [ 1 0 0 0 0; 0 0 1 0 0; 0 0 0 0 1 ]; 
model.C_xy_posn= [ 1 0 0 0 0; 0 0 1 0 0 ];
model.D= .5*dR;   %std for TDOA
%model.D= .1;   %std for TDOA
Q= P;                           %no. of sensors
model.sensor_posns= zeros(3,2,Q); %sensor location vectors: 1col vector is reference sensor posn.
model.sensor_posns= x_sensor;

%=== allocate TDOA variables to MPHD
Z= cell(Q,K);
for q=1:Q
    for k=1:K
        Z{q,k}= n_pts(peak_pt_indices{k,q})*dR; %conversion of TDOA to relative dist.
    end;
end;

N_true= ones(K,1);
track_list= cell(K,1);
X= cell(K,1);
for k=1:K
    X{k}= [ x_s(1); 0; x_s(2); 0; x_s(3) ];
    track_list{k}= 1;
end;
total_tracks= 1;

