%--- difference from sigen_test1: set up some threshold
%---
head_test1

%--- signal generation
y= zeros(N,2,P);    %received signal
ys= zeros(N,2,P);   %received signal without noise
for p=1:P
    ys(:,1,p)= fftfilt(h(:,1,p),s);
    ys(:,2,p)= fftfilt(h(:,2,p),s);
end;

ys_pow= sum(sum(sum(abs(ys).^2)))/(N*2*P);
sigma_n= sqrt(ys_pow/snr);
y= ys+ randn(N,2,P)*sigma_n;

%--- xcorrelation computation
Sy1y2= cell(P,1);   %short-time cross spectral density between two microphones
for p=1:P
    Sy1y2{p}= st_xsd(y(:,1,p),y(:,2,p),Nframe,block_overlap);
end;
L= size(Sy1y2{1},2);   %no. of short-time frames

%generate a time interpolated DFT, partial on the TDOA range of interest
pts_per_sample= 1;
n_pts= -max_d:(1/pts_per_sample):max_d;
pDFT= zeros(length(n_pts),Nframe);  
for n=1:length(n_pts)
    temp= exp( -i*2*pi*(0:1:(Nframe/2))*n_pts(n)/Nframe );
    pDFT(n,:)= [ temp fliplr(conj(temp(2:(Nframe/2)))) ];
    %pDFT(n,:)= exp( i*2*pi*(0:1:(Nframe-1))*n_pts(n)/Nframe );
end;

cc= zeros(length(n_pts),L,P);     %cross correlation functions
for l=1:L
    for p=1:P
        %uncommenting this line leads to PHAT
        %Sy1y2{p}(:,l)= Sy1y2{p}(:,l)./abs(Sy1y2{p}(:,l));    
        cc(:,l,p)= real(pDFT*Sy1y2{p}(:,l));
        %uncommenting the following line leads to normalization
        %cc(:,l,p)= cc(:,l,p)/norm(cc(:,l,p));
    end;
end;

%--- peak picking
max_peaks= 4;
upp_bound_factor= .5;
len_n_pts= length(n_pts);
peak_pt_indices= cell(L,P);
for l=1:L
    for p=1:P
        cc_temp= cc(:,l,p);
        diff1_cc= cc_temp(2:(len_n_pts-1))- cc_temp(1:(len_n_pts-2));
        diff2_cc= cc_temp(2:(len_n_pts-1))- cc_temp(3:len_n_pts);
        idx= find( diff1_cc>0 & diff2_cc>0 & cc_temp(2:(len_n_pts-1))>0 );
        idx= idx+1;
        if ~isempty(idx)
            [notused,idx2]= sort(-cc_temp(idx));
            idx= idx(idx2);
            if length(idx) > max_peaks,
                idx= idx(1:max_peaks);
            end;
            %threshold= upp_bound_factor*cc_temp(idx(1));
            threshold= max([ upp_bound_factor*cc_temp(idx(1)) sigma_n^2 ]);
            idx2= find(cc_temp(idx)>= threshold);
            peak_pt_indices{l,p}= idx(idx2);
        end;
    end;
end;


%--- plot the cross correlation functions for visualization
ell=1:L;
for p=1:P
    %true_tdoa= norm( x_s(1:2)- x_sensor(1:2,2,p) )- norm( x_s(1:2)- x_sensor(1:2,1,p) )/dR;
    true_tdoa= (norm( x_s(:)- x_sensor(:,2,p) )- norm( x_s(:)- x_sensor(:,1,p) ))/dR;
    figure(p); clf;
    subplot(211);   %
    pcolor(ell,n_pts,cc(:,:,p)); shading interp;
    hold on;
    plot(ell,true_tdoa*ones(1,L),'k','linewidth',3);
    for l=1:L
        if ~isempty(peak_pt_indices{l,p}), 
            plot(l, n_pts(peak_pt_indices{l,p}), 'or' ); 
            plot(l, n_pts(peak_pt_indices{l,p}(1)), 'r*' );
        end;
    end;
    subplot(212);
    for w=1:L
        plot(n_pts,cc(:,w,p)); hold on;
    end;
    temp_max= max(max(cc(:,:,p)));  temp_min= min(min(cc(:,:,p)));
    plot( [true_tdoa true_tdoa], [temp_min temp_max], 'r' );
end;